@@ -12,10 +12,15 @@ import jinja2
 import argparse
 import traceback
 import pathlib
-import filter_extensions
 import inspect
 
 baseDir = os.path.dirname(os.path.abspath(__file__))
+if __name__ == '__main__':
+  from imports import filter_extensions
+else:
+  sys.path.insert(0, baseDir)
+  from imports import filter_extensions
+  sys.path.pop(0)
 
 if not os.path.exists(f'{baseDir}/version'):
   print(f"Jinny's version file doesn't exist, expected to find it at {basedir}/version. Not a good sign, might be best to reinstall jinny!")
